climpred.classes.HindcastEnsemble.compute\_persistence
======================================================

.. currentmodule:: climpred.classes

.. automethod:: HindcastEnsemble.compute_persistence
